# eddy-footprint: Eddy covariance footprint modeling

A Python library for creating eddy covariance flux footprints using multiple analytical models.

## Installation

eddy-footprint can be installed from PyPI as:

    python -m pip install eddy_footprint

Or from source as:

    python -m pip install git+https://github.com/arctic-carbon/eddy-footprint.git

Note:
The required dependencies installed with eddy-footprint are [Xarray](https://xarray.dev/),
[SciPy](https://www.scipy.org/), and [NumPy](https://numpy.org/).

## Documentation

Documentation is hosted on ReadTheDocs: https://eddy-footprint.readthedocs.io/en/latest

## license

All the code in this repository is [MIT](https://choosealicense.com/licenses/mit/) licensed.
